assert_approx_equal

Function assert_approx_equal 

pub fn assert_approx_equal(actual: f64, expected: f64)
Asserts that two floating-point numbers agree to the default tolerances.

Panics with both values and the absolute and relative errors.

Panics

If the values differ by more than the default tolerances.