pub fn assert_approx_equal(actual: f64, expected: f64)Expand description
Asserts that two floating-point numbers agree to the default tolerances.
Panics with both values and the absolute and relative errors.
Panics
If the values differ by more than the default tolerances.